//***************** (c) 2008 BTC Korporacja ***********************************
//                     http://www kamami.com
// PROJECT  : ADC_POT
// BOARD    : ZL4ST7 (with ST7FLI49M)
// COMPILER : RKitSTM8 for Ride7
//
//******************************************************************************
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//******************************************************************************
//
// DESCRIPTION :
//    Simple AD conversion. Input voltage is selected by potentiometer P2.
//    Result of conversion is displayed on LCD.
//
//    Settings and connections on ZL4ST7:
//        JP4 (DISPLAY) - 2-3 (=CHAR)
//
//        D4 (LCD_CHAR/con13) - PB4 (con16)
//        D5 (LCD_CHAR/con13) - PB5 (con16)
//        D6 (LCD_CHAR/con13) - PB6 (con16)
//        D7 (LCD_CHAR/con13) - PB7 (con16)
//        E  (LCD_CHAR/con13) - PB2 (con16)
//        RS (LCD_CHAR/con13) - PB0 (con16)
//        RW (LCD_CHAR/con13) - GND (con16)
//
//        P2 (con7) - PC0 (con17)
//
//******************************************************************************
#include <ST7LITE4.H>
#include "HD44780.h"

//-------------------------------------
// Get analog input value
//-------------------------------------
unsigned int GetADC(unsigned char channel)
{
unsigned int value = 0;
ADCDRL |= (1 << 3);// SLOW
ADCCSR = channel; //
ADCCSR |= (1 << 5); // ADON
while(!(ADCCSR&(1 << 7)));// wait for EOC
value = (ADCDRL & 0x03); //
value |= (ADCDRH << 2);  // 
ADCCSR &= ~(1 << 5); // clear ADON
return value;
}
//-------------------------------------
// main program
//-------------------------------------
int main(void)
{
char str[5];
int voltage;

LCD_Initialize();

// infinite loop
do{
  voltage = GetADC(8);
  LCD_GoTo(0,0);  
  LCD_WriteText("ADC Input Value:");
  LCD_GoTo(0,1);
  LCD_WriteText(Hex((char) (voltage >> 8), str));
  LCD_WriteText(Hex((char) (voltage & 255), str));

}while(1);

return 0;
}
//-------------------------------------
// End of file
//-------------------------------------
